==> ph-ubl21-6.6.3-sources.jar: oasis/names/specification/ubl/schema/xsd/transportservicedescriptionrequest_21/ObjectFactory.java <==

package oasis.names.specification.ubl.schema.xsd.transportservicedescriptionrequest_21;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;
import com.helger.commons.annotation.CodingStyleguideUnaware;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the oasis.names.specification.ubl.schema.xsd.transportservicedescriptionrequest_21 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.<p>This class was annotated by ph-jaxb22-plugin -Xph-annotate</p>
 * 
 * 
 */
@XmlRegistry
@CodingStyleguideUnaware
public class ObjectFactory {

    public final static QName _TransportServiceDescriptionRequest_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:TransportServiceDescriptionRequest-2", "TransportServiceDescriptionRequest");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: oasis.names.specification.ubl.schema.xsd.transportservicedescriptionrequest_21
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link TransportServiceDescriptionRequestType }
     * 
     * @return
     *     The created TransportServiceDescriptionRequestType object and never <code>null</code>.
     */
    @Nonnull
    public TransportServiceDescriptionRequestType createTransportServiceDescriptionRequestType() {
        return new TransportServiceDescriptionRequestType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TransportServiceDescriptionRequestType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link TransportServiceDescriptionRequestType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:TransportServiceDescriptionRequest-2", name = "TransportServiceDescriptionRequest")
    @Nonnull
    public JAXBElement<TransportServiceDescriptionRequestType> createTransportServiceDescriptionRequest(
        @Nullable
        final TransportServiceDescriptionRequestType value) {
        return new JAXBElement<TransportServiceDescriptionRequestType>(_TransportServiceDescriptionRequest_QNAME, TransportServiceDescriptionRequestType.class, null, value);
    }

}

==> ph-ubl21-6.7.0-sources.jar: oasis/names/specification/ubl/schema/xsd/transportservicedescriptionrequest_21/ObjectFactory.java <==

package oasis.names.specification.ubl.schema.xsd.transportservicedescriptionrequest_21;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;
import com.helger.commons.annotation.CodingStyleguideUnaware;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the oasis.names.specification.ubl.schema.xsd.transportservicedescriptionrequest_21 package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.&lt;p&gt;This class was annotated by ph-jaxb22-plugin -Xph-annotate&lt;/p&gt;
 * 
 * 
 */
@XmlRegistry
@CodingStyleguideUnaware
public class ObjectFactory {

    public final static QName _TransportServiceDescriptionRequest_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:TransportServiceDescriptionRequest-2", "TransportServiceDescriptionRequest");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: oasis.names.specification.ubl.schema.xsd.transportservicedescriptionrequest_21
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link TransportServiceDescriptionRequestType }
     * 
     * @return
     *     The created TransportServiceDescriptionRequestType object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public TransportServiceDescriptionRequestType createTransportServiceDescriptionRequestType() {
        return new TransportServiceDescriptionRequestType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TransportServiceDescriptionRequestType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link TransportServiceDescriptionRequestType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:TransportServiceDescriptionRequest-2", name = "TransportServiceDescriptionRequest")
    @Nonnull
    public JAXBElement<TransportServiceDescriptionRequestType> createTransportServiceDescriptionRequest(
        @Nullable
        final TransportServiceDescriptionRequestType value) {
        return new JAXBElement<TransportServiceDescriptionRequestType>(_TransportServiceDescriptionRequest_QNAME, TransportServiceDescriptionRequestType.class, null, value);
    }

}
